@@ -1,7 +1,7 @@
 params <-
   list(EVAL = TRUE)
 
-## ----echo = FALSE----------------------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
@@ -11,7 +11,7 @@ knitr::opts_chunk$set(
 )
 
 
-## ----setup, include=FALSE--------------------------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------
 knitr::opts_chunk$set(
   echo = TRUE,
   dpi = 100,
@@ -25,15 +25,15 @@ library(ggplot2)
 theme_set(theme_bw(base_size = 12, base_family = "serif"))
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 load(url("https://github.com/atsa-es/MARSS/raw/master/data/lakeWAplankton.rda"))
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 outcomes <- c("Greens", "Bluegreens", "Diatoms", "Unicells", "Other.algae")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 # loop across each plankton group to create the long datframe
 plankton_data <- do.call(
   rbind,
@@ -62,19 +62,19 @@ plankton_data <- do.call(
   dplyr::ungroup()
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 head(plankton_data)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 dplyr::glimpse(plankton_data)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot_mvgam_series(data = plankton_data, series = "all")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plankton_data %>%
   dplyr::filter(series == "Other.algae") %>%
   ggplot(aes(x = time, y = temp)) +
@@ -86,7 +86,7 @@ plankton_data %>%
   ggtitle("Temperature (black) vs Other algae (red)")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plankton_data %>%
   dplyr::filter(series == "Diatoms") %>%
   ggplot(aes(x = time, y = temp)) +
@@ -98,14 +98,14 @@ plankton_data %>%
   ggtitle("Temperature (black) vs Diatoms (red)")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plankton_train <- plankton_data %>%
   dplyr::filter(time <= 112)
 plankton_test <- plankton_data %>%
   dplyr::filter(time > 112)
 
 
-## ----notrend_mod, include = FALSE, results='hide'--------------------------------------------
+## ----notrend_mod, include = FALSE, results='hide'-----------------------
 notrend_mod <- mvgam(
   y ~
     te(temp, month, k = c(4, 4)) +
@@ -118,7 +118,7 @@ notrend_mod <- mvgam(
 )
 
 
-## ----eval=FALSE------------------------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------
 # notrend_mod <- mvgam(
 #   y ~
 #     # tensor of temp and month to capture
@@ -133,39 +133,39 @@ notrend_mod <- mvgam(
 #   trend_model = "None"
 # )
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot_mvgam_smooth(notrend_mod, smooth = 1)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot_mvgam_smooth(notrend_mod, smooth = 2)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot_mvgam_smooth(notrend_mod, smooth = 3)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(notrend_mod, type = "forecast", series = 1)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(notrend_mod, type = "forecast", series = 2)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(notrend_mod, type = "forecast", series = 3)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(notrend_mod, type = "residuals", series = 1)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(notrend_mod, type = "residuals", series = 3)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 priors <- get_mvgam_priors(
   # observation formula, which has no terms in it
   y ~ -1,
@@ -182,22 +182,22 @@ priors <- get_mvgam_priors(
 )
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 priors[, 3]
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 priors[, 4]
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 priors <- c(
   prior(normal(0.5, 0.1), class = sigma_obs, lb = 0.2),
   prior(normal(0.5, 0.25), class = sigma)
 )
 
 
-## ----var_mod, include = FALSE, results='hide'------------------------------------------------
+## ----var_mod, include = FALSE, results='hide'---------------------------
 var_mod <- mvgam(
   y ~ -1,
   trend_formula = ~
@@ -219,10 +219,10 @@ var_mod <- mvgam(
 )
 
 
-## ----eval=FALSE------------------------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------
 # var_mod <- mvgam(
 #   # observation formula, which is empty
-#   y ~ -1,
+#   forumla = y ~ -1,
 #
 #   # process model formula, which includes the smooth functions
 #   trend_formula = ~ te(temp, month, k = c(4, 4)) +
@@ -239,46 +239,46 @@ var_mod <- mvgam(
 #   silent = 2
 # )
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 summary(var_mod, include_betas = FALSE)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(var_mod, "smooths", trend_effects = TRUE)
 
 
-## ----warning=FALSE, message=FALSE------------------------------------------------------------
-A_pars <- matrix(NA, nrow = 5, ncol = 5)
-for (i in 1:5) {
-  for (j in 1:5) {
-    A_pars[i, j] <- paste0("A[", i, ",", j, "]")
-  }
-}
-mcmc_plot(var_mod, variable = as.vector(t(A_pars)), type = "hist")
+## ----warning=FALSE, message=FALSE---------------------------------------
+mcmc_plot(
+  var_mod,
+  variable = 'A',
+  regex = TRUE,
+  type = 'hist',
+  facet_args = list(dir = 'v')
+)
 
 
-## ----warning=FALSE, message=FALSE------------------------------------------------------------
-Sigma_pars <- matrix(NA, nrow = 5, ncol = 5)
-for (i in 1:5) {
-  for (j in 1:5) {
-    Sigma_pars[i, j] <- paste0("Sigma[", i, ",", j, "]")
-  }
-}
-mcmc_plot(var_mod, variable = as.vector(t(Sigma_pars)), type = "hist")
+## ----warning=FALSE, message=FALSE---------------------------------------
+mcmc_plot(
+  var_mod,
+  variable = 'Sigma',
+  regex = TRUE,
+  type = 'hist',
+  facet_args = list(dir = 'v')
+)
 
 
-## ----warning=FALSE, message=FALSE------------------------------------------------------------
+## ----warning=FALSE, message=FALSE---------------------------------------
 mcmc_plot(var_mod, variable = "sigma_obs", regex = TRUE, type = "hist")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 priors <- c(
   prior(normal(0.5, 0.1), class = sigma_obs, lb = 0.2),
   prior(normal(0.5, 0.25), class = sigma)
 )
 
 
-## ----varcor_mod, include = FALSE, results='hide'---------------------------------------------
+## ----varcor_mod, include = FALSE, results='hide'------------------------
 varcor_mod <- mvgam(
   y ~ -1,
   trend_formula = ~
@@ -300,10 +300,10 @@ varcor_mod <- mvgam(
 )
 
 
-## ----eval=FALSE------------------------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------
 # varcor_mod <- mvgam(
 #   # observation formula, which remains empty
-#   y ~ -1,
+#   formula = y ~ -1,
 #
 #   # process model formula, which includes the smooth functions
 #   trend_formula = ~ te(temp, month, k = c(4, 4)) +
@@ -320,48 +320,50 @@ varcor_mod <- mvgam(
 #   silent = 2
 # )
 
-## ----warning=FALSE, message=FALSE------------------------------------------------------------
-Sigma_pars <- matrix(NA, nrow = 5, ncol = 5)
-for (i in 1:5) {
-  for (j in 1:5) {
-    Sigma_pars[i, j] <- paste0("Sigma[", i, ",", j, "]")
-  }
-}
-mcmc_plot(varcor_mod, variable = as.vector(t(Sigma_pars)), type = "hist")
-
-
-## --------------------------------------------------------------------------------------------
-Sigma_post <- as.matrix(varcor_mod, variable = "Sigma", regex = TRUE)
-median_correlations <- cov2cor(matrix(
-  apply(Sigma_post, 2, median),
-  nrow = 5,
-  ncol = 5
-))
-rownames(median_correlations) <- colnames(median_correlations) <- levels(
-  plankton_train$series
+## ----warning=FALSE, message=FALSE---------------------------------------
+mcmc_plot(
+  varcor_mod,
+  variable = 'Sigma',
+  regex = TRUE,
+  type = 'hist',
+  facet_args = list(dir = 'v')
 )
 
+
+## -----------------------------------------------------------------------
+Sigma_post <- as.matrix(
+  varcor_mod,
+  variable = "Sigma",
+  regex = TRUE
+)
+median_correlations <- cov2cor(
+  matrix(apply(Sigma_post, 2, median), nrow = 5, ncol = 5)
+)
+rownames(median_correlations) <-
+  colnames(median_correlations) <-
+    levels(plankton_train$series)
+
 round(median_correlations, 2)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 irfs <- irf(varcor_mod, h = 12)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 summary(irfs)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 plot(irfs, series = 3)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 fevds <- fevd(varcor_mod, h = 12)
 plot(fevds)
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 # create forecast objects for each model
 fcvar <- forecast(var_mod)
 fcvarcor <- forecast(varcor_mod)
@@ -385,7 +387,7 @@ plot(
 abline(h = 0, lty = "dashed")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 # plot the difference in energy scores; a negative value means the VAR1cor model is better, while a positive value means the VAR1 model is better
 diff_scores <- score(fcvarcor, score = "energy")$all_series$score -
   score(fcvar, score = "energy")$all_series$score
@@ -405,19 +407,19 @@ plot(
 abline(h = 0, lty = "dashed")
 
 
-## --------------------------------------------------------------------------------------------
+## -----------------------------------------------------------------------
 description <- how_to_cite(varcor_mod)
 
 
-## ----eval = FALSE----------------------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------
 # description
 
-## ----echo=FALSE------------------------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------
 cat("Methods text skeleton\n")
 cat(insight::format_message(description$methods_text))
 
 
-## ----echo=FALSE------------------------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------
 cat("\nPrimary references\n")
 for (i in seq_along(description$citations)) {
   cat(insight::format_message(description$citations[[i]]))
